@@ -3,9 +3,19 @@ from typing import Tuple, List
 import requests
 import whois
 from termcolor import colored
+from requests.packages.urllib3.util import Retry
+from requests.adapters import HTTPAdapter
+from requests import Session
 
 from servergrimoire.plugin import Plugin
 
+TIMEOUT = 5
+s = Session()
+retries = Retry(total=3, backoff_factor=0)
+adapter = HTTPAdapter(max_retries=retries)
+s.mount("https://", adapter)
+s.mount("http://", adapter)
+
 
 class PageChecker(Plugin):
     def can_handle(self, directive: str) -> bool:
@@ -18,14 +28,22 @@ class PageChecker(Plugin):
     def execute(self, directive: str, data: dict) -> dict:
         w = whois.whois(data["url"])
         try:
-            if "https" not in data["url"]:
-                url = f"https://{data['url']}"
-            else:
-                url = data["url"]
-            status_code = requests.head(url, allow_redirects=True).status_code
-        except requests.exceptions.SSLError:
-            url = f"http://{data['url']}"
-            status_code = requests.head(url, allow_redirects=True).status_code
+            try:
+                if "https" not in data["url"]:
+                    url = f"https://{data['url']}"
+                else:
+                    url = data["url"]
+                status_code = s.head(
+                    url, allow_redirects=True, timeout=TIMEOUT
+                ).status_code
+            except requests.exceptions.SSLError:
+                url = f"http://{data['url']}"
+                status_code = s.head(
+                    url, allow_redirects=True, timeout=TIMEOUT
+                ).status_code
+        except requests.exceptions.ConnectTimeout:
+            status_code = 408
+
         self.logger.info(w)
         output_strng = {
             "status": status_code,
